@@ -1,5 +1,5 @@
 /* IPwatchD - IP conflict detection tool for Linux
- * Copyright (C) 2007-2010 Jaroslav Imrich <jariq(at)jariq(dot)sk>
+ * Copyright (C) 2007-2018 Jaroslav Imrich <jariq(at)jariq(dot)sk>
  * 
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -41,13 +41,6 @@ int ipwd_daemonize (void)
 		return (IPWD_RV_ERROR);
 	}
 
-	/* If parent of this process is init we are already in daemon mode */
-	if (getppid () == 1)
-	{
-		ipwd_message (IPWD_MSG_TYPE_INFO, "Already running as daemon");
-		return (IPWD_RV_SUCCESS);
-	}
-
 	/* Fork child process */
 	pid_t pid = fork ();
 	if (pid < 0)
@@ -133,6 +126,7 @@ int ipwd_create_pidfile (void)
 
 	if (fprintf (fw, "%d", getpid()) < 0) {
 		ipwd_message (IPWD_MSG_TYPE_ERROR, "Unable to write process PID into PID file %s", IPWD_PIDFILE);
+		fclose (fw);
 		return (IPWD_RV_ERROR);
 	}
 
@@ -154,21 +148,25 @@ int ipwd_check_pidfile (void)
 {
 
 	FILE * fr = NULL;
-	char proc_this[PATH_MAX];
+	char proc_this_lnk[PATH_MAX];
+	char proc_this_bin[PATH_MAX];
 	int  proc_this_pid = -1;
-	char proc_pidfile[PATH_MAX];
+	char proc_pidfile_lnk[PATH_MAX];
+	char proc_pidfile_bin[PATH_MAX];
 	int  proc_pidfile_pid = -1;
 
 	/* Fill buffers with nulls */
-	memset (proc_this, '\0', PATH_MAX);
-	memset (proc_pidfile, '\0', PATH_MAX);
+	memset (proc_this_lnk, '\0', PATH_MAX);
+	memset (proc_this_bin, '\0', PATH_MAX);
+	memset (proc_pidfile_lnk, '\0', PATH_MAX);
+	memset (proc_pidfile_bin, '\0', PATH_MAX);
 
 	/* Determine absolute path of executable for current process */
 	proc_this_pid = getpid ();
 
-	snprintf (proc_this, PATH_MAX, "/proc/%d/exe", proc_this_pid);
+	snprintf (proc_this_lnk, PATH_MAX, "/proc/%d/exe", proc_this_pid);
 
-	if (readlink (proc_this, proc_this, PATH_MAX) <= 0)
+	if (readlink (proc_this_lnk, proc_this_bin, PATH_MAX) <= 0)
 	{
 		ipwd_message (IPWD_MSG_TYPE_ERROR, "Unable to get information about current process");
 		return (IPWD_RV_ERROR);
@@ -190,6 +188,7 @@ int ipwd_check_pidfile (void)
 	if (fscanf (fr, "%d", &proc_pidfile_pid) != 1)
 	{
 		ipwd_message (IPWD_MSG_TYPE_ERROR, "Unable to read PID from PID file %s", IPWD_PIDFILE);
+		fclose (fr);
 		return (IPWD_RV_ERROR);
 	}
 
@@ -200,9 +199,9 @@ int ipwd_check_pidfile (void)
 	}
 
 	/* Determine absolute path of executable for process specified in PID file */
-	snprintf (proc_pidfile, PATH_MAX, "/proc/%d/exe", proc_pidfile_pid);
+	snprintf (proc_pidfile_lnk, PATH_MAX, "/proc/%d/exe", proc_pidfile_pid);
 
-	if (readlink (proc_pidfile, proc_pidfile, PATH_MAX) <= 0)
+	if (readlink (proc_pidfile_lnk, proc_pidfile_bin, PATH_MAX) <= 0)
 	{
 		if (errno == ENOENT)
 		{
@@ -215,7 +214,7 @@ int ipwd_check_pidfile (void)
 	}
 
 	/* Compare absolute path of executable for current process with absolute path of executable for process specified in PID file */
-	if (strcmp (proc_this, proc_pidfile) == 0)
+	if (strcmp (proc_this_bin, proc_pidfile_bin) == 0)
 	{
 		ipwd_message (IPWD_MSG_TYPE_ERROR, "IPwatchD is already running");
 		return (IPWD_MSG_TYPE_ERROR);
